@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.64 2007/03/17 22:28:31 bowkenken Exp $
+* $Id: amenu.c,v 1.67 2007/05/11 00:42:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -444,6 +444,21 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 			MSG_TTL_AUTO_MARK_MAX_LEN );
 }
 
+/***************************************************************
+* Сν
+* long ls_mbr_n : СΥꥹֹ
+***************************************************************/
+
+void	init_auto_mark_new_mbr( long ls_mbr_n )
+{
+	long	j;
+
+	/*  */
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ )
+		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
+}
+
 /***************************************************************
 * ΥСʥå
 * long ls_mbr_n : СΥꥹֹ
@@ -683,8 +698,6 @@ void	set_menu_auto_mark( menu_t **dflt )
 	for( i = 0; i < AUTO_MARK_MAX_N; i++ ){
 		long	kk;
 
-		kk = k;
-
 		if( i == auto_mark_cur_n )
 			*dflt = &(p[k]);
 
@@ -705,6 +718,8 @@ void	set_menu_auto_mark( menu_t **dflt )
 			key = 'A';
 		}
 
+		kk = k;
+
 		sprintf( buf, "%*s%s%s",
 				(int)left_max_len,
 				get_msg_ttl_auto_mark_info( i ),
@@ -969,6 +984,18 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 	case AUTO_MARK_COND_STAGGER:
 	case AUTO_MARK_COND_OWN:
 		return FALSE;
+	case AUTO_MARK_COND_HP_MIN:
+		mnstr = get_mnstr_hp_min( mbr->x, mbr->y );
+		break;
+	case AUTO_MARK_COND_HP_MAX:
+		mnstr = get_mnstr_hp_max( mbr->x, mbr->y );
+		break;
+	case AUTO_MARK_COND_MP_MIN:
+		mnstr = get_mnstr_mp_min( mbr->x, mbr->y );
+		break;
+	case AUTO_MARK_COND_MP_MAX:
+		mnstr = get_mnstr_mp_max( mbr->x, mbr->y );
+		break;
 	}
 	if( mnstr == NULL )
 		return FALSE;
@@ -1062,6 +1089,11 @@ bool_t	exec_menu_auto_mark_item( mbr_t *mbr )
 	case AUTO_MARK_COND_OWN:
 		item = get_item_own( mbr, act_kind, TRUE );
 		break;
+	case AUTO_MARK_COND_HP_MIN:
+	case AUTO_MARK_COND_HP_MAX:
+	case AUTO_MARK_COND_MP_MIN:
+	case AUTO_MARK_COND_MP_MAX:
+		return FALSE;
 	}
 	if( item == NULL )
 		return FALSE;
@@ -1154,6 +1186,10 @@ bool_t	exec_menu_auto_mark_door( mbr_t *mbr )
 		break;
 	case AUTO_MARK_COND_STAGGER:
 	case AUTO_MARK_COND_OWN:
+	case AUTO_MARK_COND_HP_MIN:
+	case AUTO_MARK_COND_HP_MAX:
+	case AUTO_MARK_COND_MP_MIN:
+	case AUTO_MARK_COND_MP_MAX:
 		return FALSE;
 	}
 	if( door == NULL )
@@ -1218,6 +1254,18 @@ bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr )
 		break;
 	case AUTO_MARK_COND_OWN:
 		return FALSE;
+	case AUTO_MARK_COND_HP_MIN:
+		p = get_mbr_hp_min();
+		break;
+	case AUTO_MARK_COND_HP_MAX:
+		p = get_mbr_hp_max();
+		break;
+	case AUTO_MARK_COND_MP_MIN:
+		p = get_mbr_mp_min();
+		break;
+	case AUTO_MARK_COND_MP_MAX:
+		p = get_mbr_mp_max();
+		break;
 	}
 	if( p == NULL )
 		return FALSE;
@@ -1740,23 +1788,51 @@ char	*cb_menu_auto_mark_cond_init(
 	case AUTO_MARK_COND_OWN:
 		s = "own";
 		break;
+	case AUTO_MARK_COND_HP_MIN:
+		s = "hp min";
+		break;
+	case AUTO_MARK_COND_HP_MAX:
+		s = "hp max";
+		break;
+	case AUTO_MARK_COND_MP_MIN:
+		s = "mp min";
+		break;
+	case AUTO_MARK_COND_MP_MAX:
+		s = "mp max";
+		break;
 	}
 	*dflt = srch_menu( *pp, s );
 
 	/* оݤ˱ƥ˥塼ܤ̵ */
 
+	set_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
+	set_flg_menu( *pp, "mp max", FLG_MENU_HIDDEN );
+
 	switch( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].trgt ){
 	case AUTO_MARK_TRGT_DOOR:
 	case AUTO_MARK_TRGT_TRAP:
-	case AUTO_MARK_TRGT_MNSTR:
 		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
 		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_ITEM:
 		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
 		break;
+	case AUTO_MARK_TRGT_MNSTR:
+		set_flg_menu( *pp, "stagger", FLG_MENU_HIDDEN );
+		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "mp max", FLG_MENU_HIDDEN );
+		break;
 	case AUTO_MARK_TRGT_MBR:
 		set_flg_menu( *pp, "own", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "hp min", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "hp max", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "mp min", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "mp max", FLG_MENU_HIDDEN );
 		break;
 	case AUTO_MARK_TRGT_UNCHANGE:
 	case AUTO_MARK_TRGT_CLEAR:
@@ -1785,24 +1861,8 @@ char	*cb_menu_auto_mark_cond_init(
 
 char	*cb_menu_auto_mark_cond( menu_t **pp, menu_t **dflt )
 {
-	switch( (auto_mark_cond_t)(long)((*pp)->arg) ){
-	case AUTO_MARK_COND_NEAREST:
-		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
-				= AUTO_MARK_COND_NEAREST;
-		break;
-	case AUTO_MARK_COND_DISPERSE:
-		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
-				= AUTO_MARK_COND_DISPERSE;
-		break;
-	case AUTO_MARK_COND_STAGGER:
-		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
-				= AUTO_MARK_COND_STAGGER;
-		break;
-	case AUTO_MARK_COND_OWN:
-		ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
-				= AUTO_MARK_COND_OWN;
-		break;
-	}
+	ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].cond
+			= (auto_mark_cond_t)(long)((*pp)->arg);
 
 	return NULL;
 }
@@ -2309,15 +2369,18 @@ char	*cb_menu_auto_mark_arrange_bottom( menu_t **pp, menu_t **dflt )
 
 /***************************************************************
 * ˥塼¤ٴ
-* menu_t **pp : ˥塼
-* menu_t **dflt : ˥塼Υǥե
+* long n : ϰ
+* long d : Ƭ(-1)/(+1)
 * return : ˥塼ΰư
 ***************************************************************/
 
 char	*menu_auto_mark_arrange( long n, long d )
 {
-	long	i, j;
+	long	i, j, k;
 	auto_mark_t	am;
+	auto_mark_appoint_item_t	item[AUTO_MARK_APPOINT_ITEM_MAX_N];
+	auto_mark_appoint_item_t	item_tmp;
+	const long	max_item = AUTO_MARK_APPOINT_ITEM_MAX_N;
 	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
 
 	if( d <= -1 )
@@ -2330,20 +2393,50 @@ char	*menu_auto_mark_arrange( long n, long d )
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		am = ls_auto_mark[i][n];
 
+		for( k = 0; k < max_item; k++ ){
+			item[k] = auto_mark_appoint_item[i][n][k];
+		}
+
 		if( d <= -1 ){
 			for( j = n - 1; j >= 0; j-- ){
 				ls_auto_mark[i][j + 1]
 						= ls_auto_mark[i][j];
+
+				for( k = 0; k < max_item; k++ ){
+					item_tmp = auto_mark_appoint_item
+							[i][j][k];
+					auto_mark_appoint_item[i][j + 1][k]
+							= item_tmp;
+				}
 			}
 
 			ls_auto_mark[i][0] = am;
+
+			for( k = 0; k < max_item; k++ ){
+				auto_mark_appoint_item
+						[i][0][k]
+						= item[k];
+			}
 		} else {
 			for( j = n + 1; j < AUTO_MARK_MAX_N; j++ ){
 				ls_auto_mark[i][j - 1]
 						= ls_auto_mark[i][j];
+
+				for( k = 0; k < max_item; k++ ){
+					item_tmp = auto_mark_appoint_item
+							[i][j][k];
+					auto_mark_appoint_item[i][j - 1][k]
+							= item_tmp;
+				}
 			}
 
 			ls_auto_mark[i][AUTO_MARK_MAX_N - 1] = am;
+
+			for( k = 0; k < max_item; k++ ){
+				auto_mark_appoint_item
+						[i][AUTO_MARK_MAX_N - 1][k]
+						= item[k];
+			}
 		}
 	}
 
@@ -2514,6 +2607,14 @@ char	*get_msg_menu_auto_mark_edit_cond( mbr_t *mbr )
 		return MSG_MENU_AUTO_MARK_COND_STAGGER;
 	case AUTO_MARK_COND_OWN:
 		return MSG_MENU_AUTO_MARK_COND_OWN;
+	case AUTO_MARK_COND_HP_MIN:
+		return MSG_MENU_AUTO_MARK_COND_HP_MIN;
+	case AUTO_MARK_COND_HP_MAX:
+		return MSG_MENU_AUTO_MARK_COND_HP_MAX;
+	case AUTO_MARK_COND_MP_MIN:
+		return MSG_MENU_AUTO_MARK_COND_MP_MIN;
+	case AUTO_MARK_COND_MP_MAX:
+		return MSG_MENU_AUTO_MARK_COND_MP_MAX;
 	}
 
 	return MSG_NOT_NULL;
