@@ -148,7 +148,9 @@ long	read_esc( long *p );
 char	*get_reg_macro( void );
 void	set_reg_macro( bool_t flg );
 void	reg_macro( long c );
+void	draw_replay( bool_t flg_redraw );
 long	get_key( bool_t flg_clr_key_buf );
+void	get_key_wait_cancel( bool_t flg_clr_key_buf );
 long	get_key_sub_1( bool_t flg_clr_key_buf );
 long	get_key_sub_2( bool_t flg_clr_key_buf );
 long	get_key_x68k( bool_t flg_clr_key_buf );
