@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.52 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: draw.h,v 1.55 2007/03/11 20:49:58 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_H
@@ -298,6 +298,8 @@ typedef enum {
 	DATA_N_RESI_ELEC,
 	DATA_N_RESI_POIS,
 
+	DATA_N_CLASS,
+
 	DATA_N_FIG,
 	DATA_N_MON,
 	DATA_N_HUN,
@@ -311,8 +313,38 @@ typedef enum {
 	DATA_N_BAR,
 	DATA_N_NIN,
 
-	DATA_N_CLASS,
+	DATA_N_ITEM_00,
+	DATA_N_ITEM_01,
+	DATA_N_ITEM_02,
+	DATA_N_ITEM_03,
+	DATA_N_ITEM_04,
+	DATA_N_ITEM_05,
+	DATA_N_ITEM_06,
+	DATA_N_ITEM_07,
+	DATA_N_ITEM_08,
+	DATA_N_ITEM_09,
+	DATA_N_ITEM_10,
+	DATA_N_ITEM_11,
+	DATA_N_ITEM_12,
+	DATA_N_ITEM_13,
+	DATA_N_ITEM_14,
+	DATA_N_ITEM_15,
 
+	DATA_N_EQUIP_WIELDING,
+	DATA_N_EQUIP_SHIELD,
+	DATA_N_EQUIP_BOW,
+	DATA_N_EQUIP_ARW,
+	DATA_N_EQUIP_HEAD,
+	DATA_N_EQUIP_NECK,
+	DATA_N_EQUIP_BODY,
+	DATA_N_EQUIP_ABOUT_BODY,
+	DATA_N_EQUIP_ARM,
+	DATA_N_EQUIP_RIGHT_HAND,
+	DATA_N_EQUIP_LEFT_HAND,
+	DATA_N_EQUIP_FEET,
+	DATA_N_EQUIP_LIGHT_SOURCE,
+
+	DATA_N_PREV_PAGE,
 	DATA_N_NEXT_PAGE,
 
 	DATA_N_MAX_N,
@@ -336,6 +368,8 @@ typedef enum {
 
 	EDIT_CLASS_TOTAL,
 
+	EDIT_CLASS_NAME,
+
 	EDIT_CLASS_FIG,
 	EDIT_CLASS_MON,
 	EDIT_CLASS_HUN,
@@ -349,8 +383,6 @@ typedef enum {
 	EDIT_CLASS_BAR,
 	EDIT_CLASS_NIN,
 
-	EDIT_CLASS_NAME,
-
 	EDIT_CLASS_PREV,
 	EDIT_CLASS_NEXT,
 
