@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.102 2007/05/12 09:20:47 bowkenken Exp $
+* $Id: dun.c,v 1.104 2007/05/21 05:40:12 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -43,7 +43,7 @@
 /* ϩɽꥢμ */
 #define	AREA_PATH	-1
 
-/* Ψ */
+/**** Ψ ****/
 
 /* ꥢˤʤΨ */
 #define	RATE_ROOM	((rate_t)50)
@@ -60,7 +60,10 @@
 /* ϩƤΨ */
 #define	RATE_HIDE_CROSS_PATH	((rate_t)80)
 
-/**/
+/* 󥹥ΥߥߥåȢǤʤΨ */
+#define	MIMIC_RATE	50
+
+/***************************************************************/
 
 /* 곬ʤο */
 #define	STAIRS_UP_MAX_N	2
@@ -71,15 +74,18 @@
 /* 겼ȽγʤޤǤεΥ */
 #define	STAIRS_MAX_R	2
 
-/* 󥹥ΥߥߥåȢǤʤΨ */
-#define	MIMIC_RATE	50
-
 /* ߤγؤƤ NPC ʿѿ */
 #define	DUN_NPC_AVE_N	6
 
+/* (NPC ʿѿ) - () / ? */
+#define	DUN_NPC_DIV_N	4
+
 /* 1ֶᤤɥõƱΥˤȽǤΥ */
 #define	DOOR_NEAR_R	4
 
+/* ܥŪи볬ؿ */
+#define	DUN_LEV_BOSS	10
+
 /***************************************************************
 * ѿ
 ***************************************************************/
@@ -649,8 +655,12 @@ void	make_dun( void )
 	/*  NPC */
 
 	npc_max_n = roll_dice( DUN_NPC_AVE_N, FALSE );
+	npc_max_n -= labs( dun.lev ) / DUN_NPC_DIV_N;
+
 	if( npc_max_n > (MNSTR_MAX_N - mnstr_n) )
 		npc_max_n = (MNSTR_MAX_N - mnstr_n);
+	if( npc_max_n < 0 )
+		npc_max_n = 0;
 
 	npc_n = 0;
 	for( i = 0; i < LOOP_MAX_4000; i++ ){
@@ -793,26 +803,21 @@ void	make_area( room_ptn_t *ptn, area_t max_n, long x, long y )
 
 bool_t	make_area_boss( room_ptn_t *ptn, area_t max_n, long x, long y )
 {
-	area_t	i;
-	long	flg;
+	long	n;
 
 	if( dun.area[y][x] != AREA_PATH )
 		return FALSE;
+	if( dun.lev == 0 )
+		return FALSE;
+	if( (labs( dun.lev ) % DUN_LEV_BOSS) != 0 )
+		return FALSE;
 
-	for( i = 0; i < max_n; i++ ){
-		if( labs( dun.lev ) < ptn[i].min_lev )
-			continue;
-		if( labs( dun.lev ) > ptn[i].max_lev )
-			continue;
-		if( sgn_l( dun.lev ) != ptn[i].sgn_lev )
-			continue;
+	n = labs( dun.lev ) / DUN_LEV_BOSS;
+	n = (n - 1 + max_n) % max_n;
 
-		flg = 0;	/* ľʿե饰 */
-		set_room( ptn, i, x, y, flg );
-		return TRUE;
-	}
+	set_room( ptn, (area_t)n, x, y, FLG_NULL );
 
-	return FALSE;
+	return TRUE;
 }
 
 /***************************************************************
