@@ -177,6 +177,12 @@ bool_t	load_game_data_acce_material_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	acce_kind_t kind
 );
+bool_t	load_game_data_potion_identified_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
+bool_t	load_game_data_scroll_identified_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	load_game_data_item_mbr_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	long ls_mbr_n
@@ -455,6 +461,12 @@ bool_t	save_game_data_acce_material_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	acce_kind_t kind
 );
+bool_t	save_game_data_potion_identified_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
+bool_t	save_game_data_scroll_identified_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	save_game_data_auto_mark_ls_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
