@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.h,v 1.12 2007/02/03 00:10:00 bowkenken Exp $
+* $Id: gfile.h,v 1.13 2007/03/17 21:57:07 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_H
@@ -35,6 +35,11 @@
 * ե
 ***************************************************************/
 
+/* ֡åȤ */
+#define	SAVE_N_SEL	-1
+/* ư֡å */
+#define	SAVE_N_AUTO	0
+
 /* ե̾Ĺ */
 #define	FILE_NAME_MAX_LEN	127
 
