@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.49 2007/02/04 17:41:35 bowkenken Exp $
+* $Id: gmain.h,v 1.51 2007/05/12 09:20:47 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
@@ -148,6 +148,9 @@ EXTERN rate_t	g_graph_scale_rate;
 /* Ϥɤɤफ? */
 EXTERN gui_key_kind_t	g_gui_key_kind;
 
+/* åθ */
+EXTERN char	*g_language;
+
 /* ХåեΥꥢ򥪥ץǻꤵ줿? */
 EXTERN bool_t	g_flg_clr_key_buf_arg_overwrite;
 
@@ -172,6 +175,9 @@ EXTERN bool_t	g_flg_use_keypad;
 /* ե졼ࡦ졼Ȥ¬ */
 EXTERN bool_t	g_flg_measure_clk_tck;
 
+/* ֡ɻμ */
+EXTERN long	g_randm_seed_save;
+
 /* ǥХå⡼ */
 EXTERN bool_t	g_flg_debug;
 
