@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.24 2007/05/12 09:20:47 bowkenken Exp $
+* $Id: mmenu.c,v 1.25 2007/05/20 15:17:08 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -2710,7 +2710,24 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 
 		item = get_mbr_item_asgn( pty->mbr[i] );
 		p = item->next;
-		for( j = 0; j < MBR_ITEM_MAX_N; j++, k++, p = p->next ){
+		j = 0;
+		if( p == item ){
+			sprintf( ls[k].path,
+					"/identify item/unknown %c",
+					(char)('A' + i) );
+			str_nz_cpy( ls[k].kind, "<Item>",
+					MENU_KIND_MAX_LEN );
+			ls[k].accel_key = (char)('A' + j);
+			ls[k].short_key[0] = '\0';
+			ls[k].n_msg = N_MSG_ITEM_UNKNOWN;
+			str_nz_cpy( ls[k].msg, MSG_ITEM_UNKNOWN,
+					MENU_MSG_MAX_LEN );
+			ls[k].call_back = cb_menu_identify_item_unknown;
+			ls[k].arg = (void *)NULL;
+			ls[k].flg = FLG_NULL;
+			k++;
+		}
+		for( j = 0; j < MBR_ITEM_MAX_N; j++, p = p->next ){
 			if( p == item )
 				break;
 
@@ -2729,6 +2746,7 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 			ls[k].call_back = cb_menu_identify_item;
 			ls[k].arg = (void *)p;
 			ls[k].flg = FLG_NULL;
+			k++;
 		}
 
 		str_nz_cpy( ls[k].path, "/identify item/--",
@@ -2770,6 +2788,13 @@ char	*cb_menu_identify_item( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_identify_item_unknown( menu_t **pp, menu_t **dflt )
+{
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
 bool_t	exec_menu_resurrection( mbr_t *mbr )
 {
 	party_t	*pty = get_party();
