@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.190 2007/05/11 00:42:16 bowkenken Exp $
+* $Id: party.c,v 1.192 2007/05/20 14:42:05 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -711,8 +711,9 @@ void	init_party_debug( void )
 
 	i = 1;
 	sub_kind.potion = POTION_KIND_RESI_PHYS;
-	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			FALSE, FALSE, FALSE );
+	inc_item( item, +5 );
 
 	i = 1;
 	sub_kind.potion = POTION_KIND_STRENGTH;
@@ -2209,6 +2210,10 @@ void	remove_mbr( mbr_t *mbr )
 	mbr_n = mbr->mbr_n;
 	ls_mbr_n = mbr->ls_mbr_n;
 
+	/* ʸ */
+
+	remove_cast_tab( ls_mbr_n );
+
 	/* item */
 
 	remove_mbr_del_item( ls_mbr_n );
@@ -2241,10 +2246,6 @@ void	remove_mbr( mbr_t *mbr )
 
 	ls_mbr[i]->mbr_n = MBR_N_NOT_JOIN;
 	ls_mbr[i]->stat |= FLG_STAT_NOT_EXIST;
-
-	/* ʸ */
-
-	remove_cast_tab( ls_mbr[i]->ls_mbr_n );
 }
 
 /**/
