@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.h,v 1.17 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: party.h,v 1.18 2007/03/19 12:45:00 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	PARTY_H
@@ -55,13 +55,21 @@ typedef chr_t	mbr_t;
 
 /* 󥫡(ѡƥΰư濴) */
 
+typedef enum {
+	SQUARE_DIR_NORTH,
+	SQUARE_DIR_EAST,
+	SQUARE_DIR_SOUTH,
+	SQUARE_DIR_WEST,
+	SQUARE_DIR_MAX_N,
+} square_dir_t;
+
 typedef struct {
 	/* ɸ */
 	long	x, y;
 	/* 1κɸ */
 	long	pre_x, pre_y;
 	/* Ƥ */
-	long	dir_x, dir_y;
+	square_dir_t	dir;
 
 	/* Ƥθ */
 	long	chr_pos_n[SQUARE_HEIGHT][SQUARE_WIDTH];
@@ -73,6 +81,8 @@ typedef struct {
 	pos_t	chr_pos[MBR_MAX_N];
 } square_t;
 
+/* ѡƥ */
+
 typedef struct {
 	mbr_t	*mbr[MBR_MAX_N];	/* С */
 	square_t	square;	/* 󥫡 */
