@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.54 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: pet.c,v 1.55 2007/05/26 12:17:19 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -602,6 +602,29 @@ bool_t	not_join_pet( pet_t *p )
 	return FALSE;
 }
 
+/***************************************************************
+* ԽäΥ꡼
+***************************************************************/
+
+void	garbage_collection_all_pet( void )
+{
+	long	i;
+	pet_t	*p;
+
+	for( i = 0; i < PET_MAX_N; i++ ){
+		p = party_pet[i];
+
+		if( p == NULL )
+			continue;
+		if( !chk_flg( p->flg_chr, FLG_CHR_CAN_DISMISSAL ) )
+			continue;
+		if( !chk_flg( p->stat, FLG_STAT_DEAD ) )
+			continue;
+
+		dismissal( p );
+	}
+}
+
 /***************************************************************
 * ڥåȤν
 * pet_t *p : ڥå
