@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.93 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: request.c,v 1.95 2007/03/10 19:42:20 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -82,7 +82,7 @@
 #define	REQUEST_EXTERMINATE_MNSTR_AVE_N	4
 
 /* ¾ΰꥹȤ򸫤μ */
-#define	REQUEST_REFRESH_PRIZE	((gold_t)(2 * MBR_MAX_N))
+#define	REQUEST_REFRESH_PRIZE	((gold_t)(1 * MBR_MAX_N))
 
 /***************************************************************
 * 󽷤ζȷиͤΨ
@@ -202,7 +202,7 @@ request_t	*make_request_randm( void )
 
 request_t	*make_request_rare_goods( request_t *req )
 {
-	long	dun_lev;
+	long	dun_lev, dun_max_lev;
 	mnstr_tab_t	*tab;
 	mnstr_lev_tab_t	*lev_tab;
 	long	limit;
@@ -212,9 +212,9 @@ request_t	*make_request_rare_goods( request_t *req )
 
 	req->kind = REQUEST_KIND_RARE_GOODS;
 
+	dun_max_lev = get_request_dun_max_lev_easy();
 	dun_lev = REQUEST_DUN_MIN_LEV_EASY;
-	dun_lev += randm( REQUEST_DUN_MAX_LEV_EASY
-			- REQUEST_DUN_MIN_LEV_EASY );
+	dun_lev += randm( dun_max_lev - REQUEST_DUN_MIN_LEV_EASY );
 
 	tab = get_mnstr_tab_rand( -dun_lev );
 	if( tab == NULL )
@@ -228,8 +228,7 @@ request_t	*make_request_rare_goods( request_t *req )
 	req->idx_mnstr_name = -1;
 
 	req->dun_min_lev = -lev_tab->min_lev;
-	req->dun_max_lev = -min_l( lev_tab->max_lev,
-			REQUEST_DUN_MAX_LEV_EASY );
+	req->dun_max_lev = -min_l( lev_tab->max_lev, dun_max_lev );
 	req->dun_true_lev = req->dun_max_lev;
 
 	limit = roll_dice( REQUEST_RARE_GOODS_AVE_LIMIT, TRUE );
@@ -264,15 +263,17 @@ request_t	*make_request_tame_mnstr( request_t *req )
 {
 	mnstr_tab_t	*tab;
 	long	limit;
+	long	dun_max_lev;
 
 	if( req == NULL )
 		return NULL;
 
 	req->kind = REQUEST_KIND_TAME_MNSTR;
 
+	dun_max_lev = get_request_dun_max_lev_easy();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_EASY,
-			REQUEST_DUN_MAX_LEV_EASY,
+			dun_max_lev,
 			REQUEST_DUN_RANGE_LEV );
 
 	tab = get_mnstr_tab_friendly();
@@ -316,15 +317,17 @@ request_t	*make_request_tame_mnstr( request_t *req )
 request_t	*make_request_rescue( request_t *req )
 {
 	long	limit;
+	long	dun_max_lev;
 
 	if( req == NULL )
 		return NULL;
 
 	req->kind = REQUEST_KIND_RESCUE;
 
+	dun_max_lev = get_request_dun_max_lev_normal();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_NORMAL,
-			REQUEST_DUN_MAX_LEV_NORMAL,
+			dun_max_lev,
 			REQUEST_DUN_RANGE_LEV );
 
 	limit = roll_dice( REQUEST_RESCUE_AVE_LIMIT, TRUE );
@@ -367,15 +370,16 @@ request_t	*make_request_tour_guide( request_t *req )
 	mnstr_tab_t	*tab;
 	mnstr_lev_tab_t	*lev_tab;
 	long	limit;
+	long	dun_max_lev;
 
 	if( req == NULL )
 		return NULL;
 
 	req->kind = REQUEST_KIND_TOUR_GUIDE;
 
+	dun_max_lev = get_request_dun_max_lev_easy();
 	dun_lev = REQUEST_DUN_MIN_LEV_EASY;
-	dun_lev += randm( REQUEST_DUN_MAX_LEV_EASY
-			- REQUEST_DUN_MIN_LEV_EASY );
+	dun_lev += randm( dun_max_lev - REQUEST_DUN_MIN_LEV_EASY );
 
 	tab = get_mnstr_tab_rand( -dun_lev );
 	if( tab == NULL )
@@ -392,8 +396,7 @@ request_t	*make_request_tour_guide( request_t *req )
 	req->mnstr_exterminate_n = 0;
 
 	req->dun_min_lev = -lev_tab->min_lev;
-	req->dun_max_lev = -min_l( lev_tab->max_lev,
-			REQUEST_DUN_MAX_LEV_EASY );
+	req->dun_max_lev = -min_l( lev_tab->max_lev, dun_max_lev );
 	req->dun_true_lev = req->dun_max_lev;
 
 	limit = roll_dice( REQUEST_TOUR_GUIDE_AVE_LIMIT, TRUE );
@@ -430,15 +433,16 @@ request_t	*make_request_exterminate( request_t *req )
 	mnstr_tab_t	*tab;
 	mnstr_lev_tab_t	*lev_tab;
 	long	limit;
+	long	dun_max_lev;
 
 	if( req == NULL )
 		return NULL;
 
 	req->kind = REQUEST_KIND_EXTERMINATE;
 
+	dun_max_lev = get_request_dun_max_lev_normal();
 	dun_lev = REQUEST_DUN_MIN_LEV_NORMAL;
-	dun_lev += randm( REQUEST_DUN_MAX_LEV_NORMAL
-			- REQUEST_DUN_MIN_LEV_NORMAL );
+	dun_lev += randm( dun_max_lev - REQUEST_DUN_MIN_LEV_NORMAL );
 
 	tab = get_mnstr_tab_rand( -dun_lev );
 	if( tab == NULL )
@@ -455,8 +459,7 @@ request_t	*make_request_exterminate( request_t *req )
 	req->mnstr_exterminate_n = 0;
 
 	req->dun_min_lev = -lev_tab->min_lev;
-	req->dun_max_lev = -min_l( lev_tab->max_lev,
-			REQUEST_DUN_MAX_LEV_NORMAL );
+	req->dun_max_lev = -min_l( lev_tab->max_lev, dun_max_lev );
 	req->dun_true_lev = req->dun_max_lev;
 
 	limit = roll_dice( REQUEST_EXTERMINATE_AVE_LIMIT, TRUE );
@@ -490,15 +493,17 @@ request_t	*make_request_exterminate( request_t *req )
 request_t	*make_request_revenge( request_t *req )
 {
 	long	limit;
+	long	dun_max_lev;
 
 	if( req == NULL )
 		return NULL;
 
 	req->kind = REQUEST_KIND_REVENGE;
 
+	dun_max_lev = get_request_dun_max_lev_normal();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_NORMAL,
-			REQUEST_DUN_MAX_LEV_NORMAL,
+			dun_max_lev,
 			REQUEST_DUN_RANGE_LEV );
 
 	req->flg_mnstr_is_npc = TRUE;
@@ -543,15 +548,17 @@ request_t	*make_request_revenge( request_t *req )
 request_t	*make_request_wanted_criminal( request_t *req )
 {
 	long	limit;
+	long	dun_max_lev;
 
 	if( req == NULL )
 		return NULL;
 
 	req->kind = REQUEST_KIND_WANTED_CRIMINAL;
 
+	dun_max_lev = get_request_dun_max_lev_normal();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_NORMAL,
-			REQUEST_DUN_MAX_LEV_NORMAL,
+			dun_max_lev,
 			REQUEST_DUN_RANGE_LEV );
 
 	req->flg_mnstr_is_npc = TRUE;
@@ -710,6 +717,70 @@ bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 	return TRUE;
 }
 
+/***************************************************************
+* κ糬ؤãͭϰ֤(٥)
+* long dun_max_lev : 糬
+* return : 糬
+***************************************************************/
+
+long	get_request_dun_max_lev_easy( void )
+{
+	return get_request_dun_max_lev(
+			REQUEST_DUN_MIN_LEV_EASY,
+			REQUEST_DUN_MAX_LEV_EASY );
+}
+
+/***************************************************************
+* κ糬ؤãͭϰ֤(̤Υ٥)
+* long dun_max_lev : 糬
+* return : 糬
+***************************************************************/
+
+long	get_request_dun_max_lev_normal( void )
+{
+	return get_request_dun_max_lev(
+			REQUEST_DUN_MIN_LEV_NORMAL,
+			REQUEST_DUN_MAX_LEV_NORMAL );
+}
+
+/***************************************************************
+* κ糬ؤãͭϰ֤
+* long dun_max_lev : 糬
+* return : 糬
+***************************************************************/
+
+long	get_request_dun_max_lev( long dun_min_lev, long dun_max_lev )
+{
+	party_t	*pty = get_party();
+	long	sign_lev, dun_lev;
+	long	i;
+
+	sign_lev = sgn_l( dun_max_lev );
+	dun_max_lev = labs( dun_max_lev );
+	dun_min_lev = labs( dun_min_lev );
+
+	dun_lev = dun_min_lev;
+
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		long	floor, base, lev;
+
+		if( chk_flg_or( pty->mbr[i]->stat,
+				FLG_STAT_NOT_EXIST ) ){
+			continue;
+		}
+
+		floor = labs( pty->mbr[i]->dun_max_lev_floor );
+		base = labs( pty->mbr[i]->dun_max_lev_base );
+		lev = max_l( floor, base );
+
+		dun_lev = max_l( dun_lev, lev );
+	}
+
+	dun_lev = min_l( dun_lev, dun_max_lev );
+
+	return( sign_lev * dun_lev );
+}
+
 /***************************************************************
 * γؤ
 * request_t *req : 
@@ -1900,15 +1971,15 @@ void	chk_finish_request_chr_dead( chr_t *chr )
 	if( chr == NULL )
 		return;
 
-	req = chr->work.request;
-	if( req == NULL )
-		return;
-
 	chk_finish_request_exterminate( chr->mnstr_kind, 1,
 			REQUEST_KIND_TOUR_GUIDE, FALSE );
 	chk_finish_request_exterminate( chr->mnstr_kind, 1,
 			REQUEST_KIND_EXTERMINATE, TRUE );
 
+	req = chr->work.request;
+	if( req == NULL )
+		return;
+
 	switch( req->kind ){
 	case REQUEST_KIND_NULL:
 		break;
