@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu-tab.h,v 1.19 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: tmenu-tab.h,v 1.20 2007/05/16 09:37:19 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TMENU_TAB_H
@@ -1778,6 +1778,15 @@ menu_t	ls_menu_inn[] = {
 		cb_menu_inn_short_stay, (void *)TRUE,
 		FLG_NULL,
 	},
+	{
+		"/inn/stay in mews",
+		"<Item>",
+		'M',
+		"",
+		N_MSG_MENU_INN_STAY_IN_MEWS, "",
+		cb_menu_inn_stay_in_mews, (void *)FALSE,
+		FLG_NULL,
+	},
 	{
 		"/inn/bath",
 		"<Branch>",
