@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.111 2007/05/12 09:20:47 bowkenken Exp $
+* $Id: tmenu.c,v 1.112 2007/05/16 09:37:19 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -2682,6 +2682,14 @@ char	*menu_inn( void )
 	sprintf( p->msg, MSG_MENU_INN_SHORT_STAY,
 			fmt_gold( get_price_inn( TRUE ) ) );
 
+	/* Ͼǰ */
+
+	p = srch_menu( ls_menu_inn, "stay in mews" );
+	if( p == NULL )
+		return STR_MENU_ERR;
+	sprintf( p->msg, MSG_MENU_INN_STAY_IN_MEWS,
+			fmt_gold( 0 ) );
+
 	/**/
 
 	return exec_menu( ls_menu_inn, NULL, NULL );
@@ -2711,7 +2719,7 @@ char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt )
 	for( mbr_n = 0; mbr_n < MBR_MAX_N; mbr_n++ )
 		add_chr_gold( pty->mbr[mbr_n], -price );
 
-	stay_inn( flg_short );
+	stay_inn( flg_short, FALSE );
 
 	return NULL;
 }
@@ -2725,6 +2733,15 @@ char	*cb_menu_inn_short_stay( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_inn_stay_in_mews( menu_t **pp, menu_t **dflt )
+{
+	stay_inn( FALSE, TRUE );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_inn_bath( menu_t **pp, menu_t **dflt )
 {
 	char	*str_goto;
