@@ -33,7 +33,7 @@ void	party_exit_shop( long dr_n );
 void	party_exit_bar( void );
 bool_t	chk_shop_open( shop_n_t shop_n, bool_t flg_print );
 bool_t	chk_package_item( item_t *item );
-void	stay_inn( bool_t flg_short_stay );
+void	stay_inn( bool_t flg_short_stay, bool_t flg_mews );
 void	take_bath( chr_t *chr );
 bool_t	set_art_name( mbr_t *mbr, item_t *art, deal_kind_t kind );
 bool_t	set_art_name_equip( mbr_t *mbr, item_t *art, equip_kind_t eq );
