@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.125 2007/05/05 21:16:08 bowkenken Exp $
+* $Id: town.c,v 1.126 2007/05/16 09:37:19 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -1586,7 +1586,7 @@ bool_t	chk_package_item( item_t *item )
 
 /**/
 
-void	stay_inn( bool_t flg_short_stay )
+void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 {
 	party_t	*pty = get_party();
 	pet_t	**pet = get_party_pet();
@@ -1613,10 +1613,12 @@ void	stay_inn( bool_t flg_short_stay )
 			continue;
 		}
 
-		/* ǤˤƤʤ HP  */
-		fx = srch_fx( &(mbr->fx), FX_KIND_POISON );
-		if( fx == NULL ){
-			mbr->abl.hp.n = mbr->abl.hp.max;
+		if( !flg_mews ){
+			/* ǤˤƤʤ HP  */
+			fx = srch_fx( &(mbr->fx), FX_KIND_POISON );
+			if( fx == NULL ){
+				mbr->abl.hp.n = mbr->abl.hp.max;
+			}
 		}
 
 		/* MP  */
